@@ -140,22 +140,25 @@ pub fn is_valid_execution_date(conclusion: Date, execution: Date) -> bool {
     conclusion <= execution && get_russian_stock_exchange_min_last_working_day(execution) <= expected_execution
 }
 
-pub fn get_russian_stock_exchange_min_last_working_day(today: Date) -> Date {
+pub fn get_russian_central_bank_min_last_working_day(today: Date) -> Date {
     // New Year holidays
     if today.month() == 1 && today.day() < 12 {
         std::cmp::max(
             today - Duration::days(10),
             Date::from_ymd(today.year() - 1, 12, 30),
         )
-    // 8 march holidays
-    } else if today.month() == 3 && today.day() == 12 {
-        today - Duration::days(4)
-    // May holidays
-    } else if today.month() == 5 && today.day() >= 3 && today.day() <= 13 {
-        today - Duration::days(5)
     // COVID-19 pandemic
     } else if today.year() == 2020 && today.month() == 4 && today.day() <= 6 {
         Date::from_ymd(2020, 3, 28)
+    // Weekends, 8 March, May and occasional COVID-19 pandemic holidays
+    } else {
+        today - Duration::days(5)
+    }
+}
+
+pub fn get_russian_stock_exchange_min_last_working_day(today: Date) -> Date {
+    if today.month() == 1 && today.day() < 4 {
+        today - Duration::days(4)
     } else {
         today - Duration::days(3)
     }
